@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.16
+Version 2.17
 
 =head1 SYNOPSIS
 
@@ -224,6 +224,18 @@ Dictionary used for "C/C++ セキュアコーディング 第2版" published in
 
     https://www.jpcert.or.jp/securecoding_book_2nd.html
 
+=item B<--exdict> microsoft.dict
+
+=item B<--microsoft>
+
+Dictionary generated from Microsoft localization style guide.
+
+    https://www.microsoft.com/ja-jp/language/styleguides
+
+Data is generated from this article:
+
+    https://www.atmarkit.co.jp/news/200807/25/microsoft.html
+
 =back
 
 =head1 INSTALL
@@ -240,10 +252,13 @@ L<https://github.com/kaz-utashiro/greple>
 
 L<https://github.com/kaz-utashiro/greple-subst>
 
-https://www.jtca.org/standardization/katakana_guide_3_20171222.pdf
+L<https://www.jtca.org/standardization/katakana_guide_3_20171222.pdf>
 
-https://www.jtf.jp/jp/style_guide/styleguide_top.html,
-https://www.jtf.jp/jp/style_guide/pdf/jtf_style_guide.pdf
+L<https://www.jtf.jp/jp/style_guide/styleguide_top.html>,
+L<https://www.jtf.jp/jp/style_guide/pdf/jtf_style_guide.pdf>
+
+L<https://www.microsoft.com/ja-jp/language/styleguides>,
+L<https://www.atmarkit.co.jp/news/200807/25/microsoft.html>
 
 =head1 AUTHOR
 
@@ -261,7 +276,7 @@ it under the same terms as Perl itself.
 
 package App::Greple::subst;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 use v5.14;
 use strict;
@@ -779,6 +794,7 @@ option --exdictdir --prologue 'sub{ say "$ENV{GREPLE_SUBST_DICT}"; exit }'
 option --jtca-katakana-guide --exdict jtca-katakana-guide-3.dict
 option --jtf-style-guide     --exdict jtf-style-guide-3.dict
 option --sccc2               --exdict sccc2.dict
+option --microsoft           --exdict microsoft.dict
 
 option --all-katakana	     --exdict all-katakana.dict
 
